@@ -181,6 +181,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -207,8 +209,8 @@ class ApiGatewayToSageMakerEndpoint(
         request_mapping_template: builtins.str,
         resource_path: builtins.str,
         api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.Role] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         resource_name: typing.Optional[builtins.str] = None,
         response_mapping_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -228,6 +230,10 @@ class ApiGatewayToSageMakerEndpoint(
         :since: 1.68.0
         :summary: Constructs a new instance of the ApiGatewayToSageMakerEndpoint class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToSageMakerEndpoint.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSageMakerEndpointProps(
             endpoint_name=endpoint_name,
             request_mapping_template=request_mapping_template,
@@ -241,22 +247,22 @@ class ApiGatewayToSageMakerEndpoint(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
@@ -284,8 +290,8 @@ class ApiGatewayToSageMakerEndpointProps:
         request_mapping_template: builtins.str,
         resource_path: builtins.str,
         api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.Role] = None,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         resource_name: typing.Optional[builtins.str] = None,
         response_mapping_template: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -302,9 +308,19 @@ class ApiGatewayToSageMakerEndpointProps:
         :summary: The properties for the ApiGatewayToSageMakerEndpointProps class.
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
+            api_gateway_props = RestApiProps(**api_gateway_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToSageMakerEndpointProps.__init__)
+            check_type(argname="argument endpoint_name", value=endpoint_name, expected_type=type_hints["endpoint_name"])
+            check_type(argname="argument request_mapping_template", value=request_mapping_template, expected_type=type_hints["request_mapping_template"])
+            check_type(argname="argument resource_path", value=resource_path, expected_type=type_hints["resource_path"])
+            check_type(argname="argument api_gateway_execution_role", value=api_gateway_execution_role, expected_type=type_hints["api_gateway_execution_role"])
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument resource_name", value=resource_name, expected_type=type_hints["resource_name"])
+            check_type(argname="argument response_mapping_template", value=response_mapping_template, expected_type=type_hints["response_mapping_template"])
         self._values: typing.Dict[str, typing.Any] = {
             "endpoint_name": endpoint_name,
             "request_mapping_template": request_mapping_template,
